@@ -8,7 +8,7 @@ use Tickit::Utils qw(substrwidth);
 use List::Util qw(min max);
 use Text::Tabs ();
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =head1 NAME
 
@@ -16,7 +16,7 @@ Tickit::Widget::FileViewer - support for viewing files in L<Tickit>.
 
 =head1 VERSION
 
-Version 0.002
+Version 0.003
 
 =head1 SYNOPSIS
 
@@ -72,6 +72,8 @@ Takes the following named parameters:
 
 =item * file - the file to load
 
+=item * line - which line to jump to
+
 =back
 
 =cut
@@ -82,6 +84,9 @@ sub configure {
 	if(my $file = delete $args{file}) {
 		$self->load_file($file);
 	}
+	if(defined(my $line = delete $args{line})) {
+		$self->cursor_line($line);
+	}
 	$self;
 }
 
@@ -140,6 +145,7 @@ sub render_to_rb {
 	for my $row ($rect->linerange) {
 		if(@line_data) {
 			# FIXME is this unicode-safe? probably not
+			local $Text::Tabs::tabstop = 4;
 			my $txt = substrwidth(Text::Tabs::expand(shift @line_data), 0, $w);
 		# $rb->goto($row, $);
 			$self->render_line_number($rb, $rect, $row, $line);
@@ -300,7 +306,7 @@ code for each line are wrapped in another widget
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
